@@ -12,9 +12,21 @@ Author: Lorenzo Coacci
 # to manage os
 import os
 # import decoratos
-from .decorators import *
+from .decorators import (
+    se,
+    sev,
+    nocrash_return,
+    nocrash_void,
+    deprecated,
+    timer
+)
 # to manage datetime, date, timedelta
-from datetime import datetime, date, timedelta, timezone
+from datetime import (
+    datetime,
+    date,
+    timedelta,
+    timezone
+)
 # - - optional packages - -
 try:
     # to manage jsons
@@ -495,6 +507,19 @@ def ask_input_int(
         else:
             return None
 
+@nocrash_return
+def ask_password(
+    password_label=None,
+    color=None
+):
+    """RETURN : The password string"""
+    if password_label is None:
+        password_label = " PASSWORD : "
+    try:
+        password = getpass.getpass(col("\t{}:  ".format(str(password)), color))
+    except Exception:
+        password = getpass.getpass("\t{}:  ".format(str(password_label)))
+    return password
 
 @nocrash_return
 def ask_input_login(
